/**
 * Types for the BTClock application
 */

export interface LedStatus {
	hex: string;
}

/**
 * Data source types
 */
export enum DataSourceType {
	BTCLOCK_SOURCE = 0,
	THIRD_PARTY_SOURCE = 1,
	NOSTR_SOURCE = 2,
	CUSTOM_SOURCE = 3
}

// Define the Status interface based on the API response structure
export interface Status {
	currentScreen: number;
	numScreens: number;
	timerRunning: boolean;
	isOTAUpdating: boolean;
	espUptime: number;
	espFreeHeap: number;
	espHeapSize: number;
	connectionStatus: {
		price: boolean;
		blocks: boolean;
		V2: boolean;
		nostr: boolean;
	};
	rssi: number;
	currency: string;
	dnd: {
		enabled: boolean;
		timeBasedEnabled: boolean;
		startTime: string;
		endTime: string;
		active: boolean;
	};
	data: string[];
	leds: Array<{
		red: number;
		green: number;
		blue: number;
		hex: string;
	}>;
	isLoaded?: boolean;
	[key: string]: unknown;
}

// Define the Settings interface based on the API response structure
export interface Settings {
	numScreens: number;
	invertedColor: boolean;
	timerSeconds: number;
	timerRunning: boolean;
	minSecPriceUpd: number;
	fullRefreshMin: number;
	wpTimeout: number;
	tzString: string;
	dataSource: number;
	mempoolInstance: string;
	mempoolSecure: boolean;
	localPoolEndpoint: string;
	nostrPubKey: string;
	nostrRelay: string;
	nostrZapNotify: boolean;
	nostrZapPubkey: string;
	ledFlashOnZap: boolean;
	fontName: string;
	availableFonts: string[];
	customEndpoint: string;
	customEndpointDisableSSL: boolean;
	ledTestOnPower: boolean;
	ledFlashOnUpd: boolean;
	ledBrightness: number;
	stealFocus: boolean;
	mcapBigChar: boolean;
	mdnsEnabled: boolean;
	otaEnabled: boolean;
	useSatsSymbol: boolean;
	useBlkCountdown: boolean;
	suffixPrice: boolean;
	disableLeds: boolean;
	mowMode: boolean;
	verticalDesc: boolean;
	suffixShareDot: boolean;
	enableDebugLog: boolean;
	hostnamePrefix: string;
	hostname: string;
	ip: string;
	txPower: number;
	gitReleaseUrl: string;
	bitaxeEnabled: boolean;
	bitaxeHostname: string;
	miningPoolStats: boolean;
	miningPoolName: string;
	miningPoolUser: string;
	availablePools: string[];
	httpAuthEnabled: boolean;
	httpAuthUser: string;
	httpAuthPass: string;
	hasFrontlight?: boolean;
	timePerScreen?: number;
	// Frontlight settings
	flDisable?: boolean;
	flMaxBrightness?: number;
	flAlwaysOn?: boolean;
	flEffectDelay?: number;
	flFlashOnUpd?: boolean;
	flFlashOnZap?: boolean;
	// Light sensor settings
	hasLightLevel?: boolean;
	luxLightToggle?: number;
	flOffWhenDark?: boolean;
	hwRev: string;
	fsRev: string;
	gitRev: string;
	gitTag: string;
	lastBuildTime: string;
	screens: Array<{
		id: number;
		name: string;
		enabled: boolean;
	}>;
	actCurrencies: string[];
	availableCurrencies: string[];
	poolLogosUrl: string;
	ceEndpoint: string;
	ceDisableSSL: boolean;
	dnd: {
		enabled: boolean;
		timeBasedEnabled: boolean;
		startHour: number;
		startMinute: number;
		endHour: number;
		endMinute: number;
	};
	isLoaded?: boolean;
	[key: string]: unknown;
}
