/**
 * Determines the appropriate firmware binary name based on hardware revision
 * @param hwRev Hardware revision string
 * @returns The firmware binary filename appropriate for this hardware
 */
export function getFirmwareBinaryName(hwRev: string): string {
	if (!hwRev) return 'blib_s3_mini_213epd_firmware.bin';

	// Default binary for unknown hardware
	let binaryName = 'blib_s3_mini_213epd_firmware.bin';

	if (hwRev.includes('s3_mini')) {
		if (hwRev.includes('29epd')) {
			binaryName = 'lolin_s3_mini_29epd_firmware.bin';
		} else {
			binaryName = 'lolin_s3_mini_213epd_firmware.bin';
		}
	} else if (hwRev.includes('rev_b')) {
		binaryName = 'btclock_rev_b_213epd_firmware.bin';
	} else if (hwRev.includes('v8')) {
		binaryName = 'btclock_v8_213epd_firmware.bin';
	}

	return binaryName;
}

/**
 * Determines the appropriate WebUI binary name based on hardware revision
 * @param hwRev Hardware revision string
 * @returns The WebUI binary filename appropriate for this hardware
 */
export function getWebUiBinaryName(hwRev: string): string {
	if (!hwRev) return 'littlefs_4MB.bin';

	// Most devices use 4MB filesystem
	let binaryName = 'littlefs_4MB.bin';

	// Devices with larger flash might use 8MB or 16MB
	if (hwRev.includes('v8')) {
		binaryName = 'littlefs_8MB.bin';
	} else if (hwRev.includes('16MB')) {
		binaryName = 'littlefs_16MB.bin';
	}

	return binaryName;
}
